
xhorizon
================================


*xhorizon*: Explicitly computing Penrose diagrams in general relativity.

A Python package.


| **I finally gave the package a makeover and updated to Python 3!**

| **The new documentation is still under construction...**
| **but there is now an ever expanding tutorial!**



Links
-----
   - `GitHub <https://github.com/xh-diagrams/xhorizon>`_.
   - `Documentation <https://xhorizon.readthedocs.io/>`_.
   - `PyPi <https://pypi.org/project/xhorizon/>`_.


Background Theory
-----------------
JC Schindler, A Aguirre. 
*Algorithms for the explicit computation of Penrose diagrams.*
`Class Quantum Grav 35 105019 <https://doi.org/10.1088/1361-6382/aabce2>`_.
(2018).
`arxiv:1802.02263 <https://arxiv.org/abs/1802.02263>`_.


Getting Started
---------------
To install::

   pip install xhorizon

To start using the tools, begin with the `tutorial <https://xhorizon.readthedocs.io/en/stable/TUTORIAL/00-overview.html>`_ and keep an eye out for `example scripts <https://github.com/xh-diagrams/xhorizon/tree/main/scripts/examples>`_.

